@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*  -*- tuareg -*-                                                        *)
 (*                                                                        *)
-(*  Copyright (C) 2017,2018 Yann Régis-Gianas, Nicolas Jeannerod,         *)
+(*  Copyright (C) 2017,2018,2019 Yann Régis-Gianas, Nicolas Jeannerod,    *)
 (*  Ralf Treinen.                                                         *)
 (*                                                                        *)
 (*  This is free software: you can redistribute it and/or modify it       *)
@@ -17,6 +17,9 @@ exception DuringParsing of Lexing.position
 (** Raise in case of parsing error. *)
 exception DuringLexing of Lexing.position * string
 
+(** Raise in case of a limitation in alias handling. *)
+exception DuringAliasing of Lexing.position * string
+
 (** Raise in case of I/O error. *)
 exception DuringIO of string
 
